@@ -312,9 +312,18 @@ class Application:
         except Exception:
             traceback.print_exc()
             pass
+
+        # Under normal circumstances, this won't trigger.
+        # But if the config has been incorrectly edited or
+        # otherwise corrupted, this can prevent a crash.
+        if 0 < self.opt.game_holded != self.opt.last_gameid:
+            self.opt.last_gameid = self.opt.game_holded
+
         # startup information
         if self.getGameClass(self.opt.last_gameid):
             self.nextgame.id = self.opt.last_gameid
+        elif self.opt.last_gameid in GI.PROTECTED_GAMES:
+            self.nextgame.id = GI.PROTECTED_GAMES.get(self.opt.last_gameid)
         # load a holded or saved game
         tmpgame = self.constructGame(self.gdb.getGamesIdSortedByName()[0])
         self._load_held_or_saved_game(tmpgame)
@@ -344,7 +353,6 @@ class Application:
         self.opt.game_holded = 0
         tmpgame.destruct()
         destruct(tmpgame)
-        tmpgame = None
         #
         # widgets
         #
@@ -794,6 +802,10 @@ class Application:
                 t1 = t0
             elif len(cs.trumps) < gi.ncards:    # not enough cards
                 t1 = t0
+        elif gc == GI.GC_MATCHING:
+            t0 = "Matching"
+            if cs.ncards < (gi.ncards / 2):    # not enough cards
+                t1 = t0
         else:
             # we should not come here
             t0 = t1 = "Unknown"
