@@ -21,27 +21,24 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import ACE, KING
+from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.hint import CautiousDefaultHint
+from pysollib.layout import Layout
 from pysollib.stack import \
         DealRowTalonStack, \
         ReserveStack, \
         SS_FoundationStack, \
         SS_RowStack, \
-        UD_SS_RowStack, \
-        StackWrapper
-from pysollib.game import Game
-from pysollib.layout import Layout
-from pysollib.hint import CautiousDefaultHint
-
+        StackWrapper, \
+        UD_SS_RowStack
+from pysollib.util import ACE, KING
 
 # ************************************************************************
 # * Carthage
 # ************************************************************************
 
+
 class Carthage_Talon(DealRowTalonStack):
     def dealCards(self, sound=False):
         if sound:
@@ -165,6 +162,6 @@ registerGame(GameInfo(321, Carthage, "Carthage",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(322, AlgerianPatience, "Algerian Patience",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_MOSTLY_SKILL))
-registerGame(GameInfo(457, AlgerianPatience3, "Algerian Patience (3 decks)",
+registerGame(GameInfo(457, AlgerianPatience3, "Algerian Patience (3 Decks)",
                       GI.GT_3DECK_TYPE | GI.GT_ORIGINAL, 3, 0,
                       GI.SL_MOSTLY_SKILL))
