@@ -241,6 +241,14 @@ class RelaxedGolf(Golf):
     shallHighlightMatch = Game._shallHighlightMatch_RKW
 
 
+class DoublePutt(DoubleGolf):
+    Solver_Class = BlackHoleSolverWrapper(preset='golf', base_rank=0,
+                                          wrap_ranks=True)
+    Waste_Class = StackWrapper(Golf_Waste, mod=13)
+
+    shallHighlightMatch = Game._shallHighlightMatch_RKW
+
+
 # ************************************************************************
 # * Elevator - Relaxed Golf in a Pyramid layout
 # ************************************************************************
@@ -512,22 +520,110 @@ class AllInARow(BlackHole):
         self._startDealNumRowsAndDealSingleRow(3)
 
 
+# ************************************************************************
+# * All in a Row II
+# ************************************************************************
+
+class AllInARowII_RowStack(BlackHole_RowStack):
+    def clickHandler(self, event):
+        return self.rightclickHandler(event)
+
+
+class AllInARowII_Reserve(RK_RowStack):
+    getBottomImage = RK_RowStack._getReserveBottomImage
+
+    def getHelp(self):
+        return _('Reserve. Build up regardless of suit.')
+
+
+class AllInARowII_Foundation(AbstractFoundationStack):
+    def acceptsCards(self, from_stack, cards):
+        if from_stack not in self.game.s.reserves:
+            return False
+        if len(cards) == 1 or len(cards) != len(from_stack.cards):
+            return False
+        return True
+
+
+class AllInARowII(Game):
+
+    def createGame(self):
+        # create layout
+        layout, s = Layout(self), self.s
+
+        # set window
+        h = layout.YM+layout.YS + 4 * layout.YOFFSET
+        self.setSize(layout.XM + 7 * layout.XS,
+                     3 * layout.YM + 3 * h + layout.YS)
+
+        # create stacks
+        x, y = layout.XM, layout.YM
+        for i in range(7):
+            s.rows.append(AllInARowII_RowStack(x, y, self, max_accept=0))
+            x += layout.XS
+        x, y = layout.XM, layout.YM+h
+        for i in range(6):
+            s.rows.append(AllInARowII_RowStack(x, y, self, max_accept=0))
+            x += layout.XS
+        for r in s.rows:
+            r.CARD_XOFFSET, r.CARD_YOFFSET = 0, layout.YOFFSET
+
+        x, y = layout.XM, self.height-layout.YS
+        stack = AllInARowII_Foundation(
+            x, y, self, ANY_SUIT, dir=0, mod=13, max_move=0, max_cards=52,
+            base_rank=ANY_RANK)
+        s.foundations.append(stack)
+        layout.createText(stack, 'se')
+
+        y -= layout.YS
+        stack = AllInARowII_Reserve(
+            x, y, self, dir=1, mod=13, max_cards=52, base_rank=ANY_RANK)
+        s.reserves.append(stack)
+        stack.CARD_XOFFSET, stack.CARD_YOFFSET = ((self.width - layout.XS)
+                                                  // 51, 0)
+        x = self.width-layout.XS
+        s.talon = InitialDealTalonStack(x, y, self)
+
+        # define stack-groups
+        layout.defaultStackGroups()
+
+    def startGame(self):
+        self._startDealNumRowsAndDealSingleRow(3)
+
+    def getStuck(self):
+        if len(self.s.reserves[0].cards) > 1:
+            return True
+        return Game.getStuck(self)
+
+
 # ************************************************************************
 # * Robert
+# * Bobby
 # * Wasatch
 # ************************************************************************
 
 class Robert(Game):
+    Foundation_Stack = BlackHole_Foundation
 
-    def createGame(self, max_rounds=3, num_deal=1):
+    def createGame(self, max_rounds=3, num_deal=1, num_foundations=1):
         layout, s = Layout(self), self.s
-        self.setSize(layout.XM+4*layout.XS, layout.YM+2*layout.YS)
-        x, y = layout.XM+3*layout.XS//2, layout.YM
-        stack = BlackHole_Foundation(x, y, self, ANY_SUIT,
-                                     dir=0, mod=13, max_move=0, max_cards=52)
-        s.foundations.append(stack)
-        layout.createText(stack, 'ne')
-        x, y = layout.XM+layout.XS, layout.YM+layout.YS
+        self.setSize(layout.XM + 4 * layout.XS,
+                     layout.YM + layout.TEXT_HEIGHT + 2 * layout.YS)
+        x, y = layout.XM, layout.YM
+        if num_foundations == 1:
+            x += 3 * layout.XS // 2
+        elif num_foundations == 2:
+            x += layout.XS
+        for f in range(num_foundations):
+            stack = self.Foundation_Stack(x, y, self, ANY_SUIT,
+                                          dir=0, mod=13, max_move=0,
+                                          max_cards=52,
+                                          base_rank=ANY_RANK)
+            s.foundations.append(stack)
+            layout.createText(stack, 's')
+            x += layout.XS
+
+        x, y = layout.XM+layout.XS, layout.YM + layout.YS + layout.TEXT_HEIGHT
         s.talon = WasteTalonStack(x, y, self,
                                   max_rounds=max_rounds, num_deal=num_deal)
         layout.createText(s.talon, 'nw')
@@ -546,13 +642,22 @@ class Robert(Game):
         self.s.talon.dealCards()
 
 
+class Bobby(Robert):
+
+    def createGame(self):
+        Robert.createGame(self, num_foundations=2)
+
+    def startGame(self):
+        self.startDealSample()
+        self.s.talon.dealRow(rows=self.s.foundations[:1])
+        self.s.talon.dealCards()
+
+
 class Wasatch(Robert):
 
     def createGame(self):
         Robert.createGame(self, max_rounds=UNLIMITED_REDEALS, num_deal=3)
 
-    def startGame(self):
-        Robert.startGame(self)
 
 # ************************************************************************
 # * Uintah
@@ -576,27 +681,12 @@ class Uintah_Foundation(AbstractFoundationStack):
         return _('Foundation. Build up or down by same color.')
 
 
-class Uintah(Game):
+class Uintah(Robert):
+    Foundation_Stack = Uintah_Foundation
 
     def createGame(self):
-        layout, s = Layout(self), self.s
-        self.setSize(layout.XM + 4 * layout.XS, layout.YM + 2 * layout.YS)
-        x, y = layout.XM, layout.YM
-        for i in range(4):
-            s.foundations.append(Uintah_Foundation(x, y, self,
-                                 suit=ANY_SUIT, dir=0, mod=13,
-                                 max_cards=52, max_move=0))
-            x += layout.XS
-        x, y = layout.XM + layout.XS, layout.YM + layout.YS
-        s.talon = WasteTalonStack(x, y, self,
-                                  max_rounds=UNLIMITED_REDEALS, num_deal=3)
-        layout.createText(s.talon, 'nw')
-        x += layout.XS
-        s.waste = WasteStack(x, y, self)
-        layout.createText(s.waste, 'ne')
-
-        # define stack-groups
-        layout.defaultStackGroups()
+        Robert.createGame(self, max_rounds=UNLIMITED_REDEALS, num_deal=3,
+                          num_foundations=4)
 
     def _shuffleHook(self, cards):
         suits = []
@@ -611,11 +701,6 @@ class Uintah(Game):
         top_cards.sort(key=lambda x: -x.suit)  # sort by suit
         return cards + top_cards
 
-    def startGame(self):
-        self.startDealSample()
-        self.s.talon.dealRow(rows=self.s.foundations)
-        self.s.talon.dealCards()
-
 
 # ************************************************************************
 # * Diamond Mine
@@ -1162,6 +1247,70 @@ class NapoleonLeavesMoscow(NapoleonTakesMoscow):
         self._startDealNumRowsAndDealRowAndCards(4)
 
 
+# ************************************************************************
+# * Carcassonne
+# ************************************************************************
+
+class Carcassonne(Game, FirTree_GameMethods):
+
+    def createGame(self):
+
+        layout, s = Layout(self), self.s
+        self.setSize(layout.XM + 10 * layout.XS,
+                     layout.YM + 3 * layout.YS + 15 * layout.YOFFSET +
+                     layout.TEXT_HEIGHT)
+
+        x, y = layout.XM+layout.XS, layout.YM
+        for i in range(4):
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i))
+            x += layout.XS
+        for i in range(4):
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i,
+                                                    dir=-1))
+            x += layout.XS
+
+        x, y = layout.XM, layout.YM+layout.YS
+        for i in range(2):
+            for j in range(4):
+                s.rows.append(UD_RK_RowStack(x, y, self, base_rank=NO_RANK))
+                x += layout.XS
+            x += 2*layout.XS
+
+        x, y = layout.XM+4*layout.XS, layout.YM+layout.YS
+        s.reserves += self._createFirTree(layout, x, y)
+
+        x, y = layout.XM, self.height - layout.YS - layout.TEXT_HEIGHT
+        s.talon = InitialDealTalonStack(x, y, self)
+
+        # define stack-groups
+        layout.defaultStackGroups()
+
+    def _shuffleHook(self, cards):
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank in (ACE, KING), (c.deck, c.rank, c.suit)))
+
+    def _fillOne(self):
+        for r in self.s.rows:
+            if r.cards:
+                c = r.cards[-1]
+                for f in self.s.foundations:
+                    if f.acceptsCards(r, [c]):
+                        self.moveMove(1, r, f, frames=3, shadow=0)
+                        return 1
+        return 0
+
+    def startGame(self):
+        self.s.talon.dealRow(rows=self.s.foundations, frames=0)
+        self._startDealNumRows(1)
+        self.s.talon.dealRow(rows=self.s.reserves, frames=0)
+        for i in range(9):
+            self.s.talon.dealRow(frames=3)
+            while True:
+                if not self._fillOne():
+                    break
+        self.s.talon.dealCards()
+
 # ************************************************************************
 # * Flake
 # * Flake (2 Decks)
@@ -1177,8 +1326,8 @@ class Flake(Game):
 
         # set window
         self.setSize(
-            layout.XM + rows*layout.XS,
-            layout.YM + 2*layout.YS + playcards*layout.XOFFSET)
+            layout.XM + rows * layout.XS,
+            layout.YM + 2 * layout.YS + playcards * layout.XOFFSET)
 
         # create stacks
         x, y, = layout.XM, layout.YM+layout.YS
@@ -1186,14 +1335,14 @@ class Flake(Game):
             s.rows.append(UD_RK_RowStack(x, y, self, mod=13))
             x += layout.XS
 
-        x, y = layout.XM + (rows-1)*layout.XS//2, layout.YM
+        x, y = layout.XM + (rows - 1) * layout.XS // 2, layout.YM
         stack = BlackHole_Foundation(x, y, self, max_move=0, suit=ANY_SUIT,
                                      base_rank=ANY_RANK, dir=0, mod=13,
-                                     max_cards=52*self.gameinfo.decks)
+                                     max_cards=52 * self.gameinfo.decks)
         s.foundations.append(stack)
         layout.createText(stack, 'ne')
 
-        x, y = layout.XM, self.height-layout.YS
+        x, y = layout.XM, layout.YM
         s.talon = InitialDealTalonStack(x, y, self)
 
         # define stack-groups
@@ -1229,10 +1378,10 @@ class Beacon(Game):
         playcards = 12
         self.setSize(
             layout.XM+rows*layout.XS,
-            layout.YM+3*layout.YS+playcards*layout.YOFFSET)
+            layout.YM + 3 * layout.YS + playcards * layout.YOFFSET)
 
         # create stacks
-        x, y = layout.XM + (rows-1)*layout.XS//2, layout.YM
+        x, y = layout.XM + (rows - 1) * layout.XS // 2, layout.YM
         stack = RK_FoundationStack(x, y, self, base_rank=ANY_RANK,
                                    max_cards=52, mod=13)
         s.foundations.append(stack)
@@ -1266,7 +1415,8 @@ class Beacon(Game):
 
 # register the game
 registerGame(GameInfo(36, Golf, "Golf",
-                      GI.GT_GOLF, 1, 0, GI.SL_BALANCED))
+                      GI.GT_GOLF, 1, 0, GI.SL_BALANCED,
+                      altnames=("One Foundation",)))
 registerGame(GameInfo(259, DeadKingGolf, "Dead King Golf",
                       GI.GT_GOLF, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(260, RelaxedGolf, "Relaxed Golf",
@@ -1282,7 +1432,8 @@ registerGame(GameInfo(267, FourLeafClovers, "Four Leaf Clovers",
 registerGame(GameInfo(281, Escalator, "Escalator",
                       GI.GT_GOLF, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(405, AllInARow, "All in a Row",
-                      GI.GT_GOLF | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_GOLF | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
+                      altnames=("Quasar",)))
 registerGame(GameInfo(432, Robert, "Robert",
                       GI.GT_GOLF, 1, 2, GI.SL_LUCK))
 registerGame(GameInfo(551, DiamondMine, "Diamond Mine",
@@ -1332,3 +1483,11 @@ registerGame(GameInfo(783, Uintah, "Uintah",
 registerGame(GameInfo(812, Sticko, "Sticko",
                       GI.GT_1DECK_TYPE | GI.GT_STRIPPED, 1, 0, GI.SL_BALANCED,
                       ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
+registerGame(GameInfo(868, Bobby, "Bobby",
+                      GI.GT_GOLF, 1, 2, GI.SL_LUCK))
+registerGame(GameInfo(880, Carcassonne, "Carcassonne",
+                      GI.GT_NAPOLEON | GI.GT_OPEN, 2, 0, GI.SL_BALANCED))
+registerGame(GameInfo(891, AllInARowII, "All in a Row II",
+                      GI.GT_GOLF | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(892, DoublePutt, "Double Putt",
+                      GI.GT_GOLF, 2, 0, GI.SL_BALANCED))
