@@ -28,7 +28,8 @@ import traceback
 import configobj
 
 import pysollib.settings
-from pysollib.mfxutil import Image, USE_PIL, print_err
+from pysollib.mfxutil import USE_PIL,\
+    get_default_resampling, print_err
 from pysollib.mygettext import _
 from pysollib.mygettext import myGettext
 from pysollib.pysoltk import STATUSBAR_ITEMS, TOOLBAR_BUTTONS, TOOLKIT
@@ -61,6 +62,7 @@ def calcCustomMouseButtonsBinding(binding_format):
 
 configspec = '''
 [general]
+last_version = list
 player = string
 confirm = boolean
 update_player_stats = boolean
@@ -77,6 +79,7 @@ highlight_piles = boolean
 highlight_cards = boolean
 highlight_samerank = boolean
 highlight_not_matching = boolean
+peek_facedown = boolean
 stuck_notification = boolean
 mahjongg_show_removed = boolean
 mahjongg_create_solvable = integer(0, 2)
@@ -210,6 +213,7 @@ resampling = integer(0, 10)
 
 class Options:
     GENERAL_OPTIONS = [
+        ('last_version', 'list'),
         ('player', 'str'),
         ('confirm', 'bool'),
         ('update_player_stats', 'bool'),
@@ -226,6 +230,7 @@ class Options:
         ('highlight_cards', 'bool'),
         ('highlight_samerank', 'bool'),
         ('highlight_not_matching', 'bool'),
+        ('peek_facedown', 'bool'),
         ('stuck_notification', 'bool'),
         ('mahjongg_show_removed', 'bool'),
         ('mahjongg_create_solvable', 'int'),
@@ -300,6 +305,8 @@ class Options:
 
         self.version_tuple = pysollib.settings.VERSION_TUPLE  # XXX
         self.saved = 0                  # XXX
+
+        self.last_version = (2, 20, 1)
         # options menu:
         self.player = _("Unknown")
         self.confirm = True
@@ -317,6 +324,7 @@ class Options:
         self.highlight_cards = True
         self.highlight_samerank = True
         self.highlight_not_matching = True
+        self.peek_facedown = False
         self.stuck_notification = False
         self.mahjongg_show_removed = False
         self.mahjongg_create_solvable = 2  # 0 - none, 1 - easy, 2 - hard
@@ -467,7 +475,8 @@ class Options:
         self.tabletile_scale_method = 0
         self.resampling = 0
         if USE_PIL:
-            self.resampling = int(Image.ANTIALIAS)
+            self.resampling = int(get_default_resampling())
+
         # solver
         self.solver_presets = [
             'none',
@@ -586,6 +595,8 @@ class Options:
     def save(self, filename):
         config = self._config
 
+        self.last_version = self.version_tuple
+
         # general
         for key, t in self.GENERAL_OPTIONS:
             val = getattr(self, key)
