@@ -122,8 +122,8 @@ class SelectGameDialogWithPreview(MfxDialog):
             ('played',      _('Played:'),           stats_frame,  0),
             ('won',         _('Won:'),              stats_frame,  1),
             ('lost',        _('Lost:'),             stats_frame,  2),
-            ('time',        _('Playing time:'),     stats_frame,  3),
-            ('moves',       _('Moves:'),            stats_frame,  4),
+            ('time',        _('Avg. win time:'),    stats_frame,  3),
+            ('moves',       _('Avg. win moves:'),   stats_frame,  4),
             ('percent',     _('% won:'),            stats_frame,  5),
                 ):
             title_label = gtk.Label()
@@ -271,9 +271,9 @@ class SelectGameDialogWithPreview(MfxDialog):
             (_("2 redeals"), lambda gi: gi.si.redeals == 2),
             (_("3 redeals"), lambda gi: gi.si.redeals == 3),
             (_("Unlimited redeals"), lambda gi: gi.si.redeals == -1),
-            # (_("Variable redeals"), lambda gi: gi.si.redeals == -2),
+            (_("Variable redeals"), lambda gi: gi.si.redeals == -2),
             (_("Other number of redeals"),
-                lambda gi: gi.si.redeals not in (-1, 0, 1, 2, 3)),)
+                lambda gi: gi.si.redeals not in (-2, -1, 0, 1, 2, 3)),)
         self._addGamesFromData(data, store, root_iter,
                                _("by Number of Redeals"), all_games)
 
@@ -483,14 +483,7 @@ class SelectGameDialogWithPreview(MfxDialog):
         type = ''
         if gi.si.game_type in GI.TYPE_NAMES:
             type = _(GI.TYPE_NAMES[gi.si.game_type])
-        sl = {
-            GI.SL_LUCK:         _('Luck only'),
-            GI.SL_MOSTLY_LUCK:  _('Mostly luck'),
-            GI.SL_BALANCED:     _('Balanced'),
-            GI.SL_MOSTLY_SKILL: _('Mostly skill'),
-            GI.SL_SKILL:        _('Skill only'),
-            }
-        skill_level = sl.get(gi.skill_level)
+        skill_level = GI.SKILL_LEVELS.get(gi.skill_level)
         if gi.redeals == -2:
             redeals = _('variable')
         elif gi.redeals == -1:
