@@ -94,32 +94,32 @@ def createResamplingMenu(menubar, menu):
                             variable=menubar.tkopt.resampling,
                             value=int(Image.NEAREST),
                             command=menubar.mOptResampling)
-    if Image.BILINEAR:
+    if hasattr(Image, "BILINEAR"):
         submenu.add_radiobutton(label=n_("&Bilinear"),
                                 variable=menubar.tkopt.resampling,
                                 value=int(Image.BILINEAR),
                                 command=menubar.mOptResampling)
-    if Image.BICUBIC:
+    if hasattr(Image, "BICUBIC"):
         submenu.add_radiobutton(label=n_("B&icubic"),
                                 variable=menubar.tkopt.resampling,
                                 value=int(Image.BICUBIC),
                                 command=menubar.mOptResampling)
-    if Image.LANCZOS:
+    if hasattr(Image, "LANCZOS"):
         submenu.add_radiobutton(label=n_("&Lanczos"),
                                 variable=menubar.tkopt.resampling,
                                 value=int(Image.LANCZOS),
                                 command=menubar.mOptResampling)
-    elif Image.ANTIALIAS:
+    elif hasattr(Image, "ANTIALIAS"):
         submenu.add_radiobutton(label=n_("&Antialiasing"),
                                 variable=menubar.tkopt.resampling,
                                 value=int(Image.ANTIALIAS),
                                 command=menubar.mOptResampling)
-    if Image.BOX:
+    if hasattr(Image, "BOX"):
         submenu.add_radiobutton(label=n_("B&ox"),
                                 variable=menubar.tkopt.resampling,
                                 value=int(Image.BOX),
                                 command=menubar.mOptResampling)
-    if Image.HAMMING:
+    if hasattr(Image, "HAMMING"):
         submenu.add_radiobutton(label=n_("&Hamming"),
                                 variable=menubar.tkopt.resampling,
                                 value=int(Image.HAMMING),
@@ -225,6 +225,7 @@ class PysolMenubarTkCommon:
             highlight_cards=tkinter.BooleanVar(),
             highlight_samerank=tkinter.BooleanVar(),
             highlight_not_matching=tkinter.BooleanVar(),
+            peek_facedown=tkinter.BooleanVar(),
             stuck_notification=tkinter.BooleanVar(),
             mahjongg_show_removed=tkinter.BooleanVar(),
             shisen_show_hint=tkinter.BooleanVar(),
@@ -242,9 +243,11 @@ class PysolMenubarTkCommon:
             animations=tkinter.IntVar(),
             redeal_animation=tkinter.BooleanVar(),
             win_animation=tkinter.BooleanVar(),
+            flip_animation=tkinter.BooleanVar(),
             shadow=tkinter.BooleanVar(),
             shade=tkinter.BooleanVar(),
             shade_filled_stacks=tkinter.BooleanVar(),
+            compact_stacks=tkinter.BooleanVar(),
             shrink_face_down=tkinter.BooleanVar(),
             randomize_place=tkinter.BooleanVar(),
             toolbar=tkinter.IntVar(),
@@ -286,9 +289,11 @@ class PysolMenubarTkCommon:
         tkopt.highlight_cards.set(opt.highlight_cards)
         tkopt.highlight_samerank.set(opt.highlight_samerank)
         tkopt.highlight_not_matching.set(opt.highlight_not_matching)
+        tkopt.peek_facedown.set(opt.peek_facedown)
         tkopt.stuck_notification.set(opt.stuck_notification)
         tkopt.shrink_face_down.set(opt.shrink_face_down)
         tkopt.shade_filled_stacks.set(opt.shade_filled_stacks)
+        tkopt.compact_stacks.set(opt.compact_stacks)
         tkopt.randomize_place.set(opt.randomize_place)
         tkopt.mahjongg_show_removed.set(opt.mahjongg_show_removed)
         tkopt.shisen_show_hint.set(opt.shisen_show_hint)
@@ -306,6 +311,7 @@ class PysolMenubarTkCommon:
         tkopt.animations.set(opt.animations)
         tkopt.redeal_animation.set(opt.redeal_animation)
         tkopt.win_animation.set(opt.win_animation)
+        tkopt.flip_animation.set(opt.flip_animation)
         tkopt.shadow.set(opt.shadow)
         tkopt.shade.set(opt.shade)
         tkopt.toolbar.set(opt.toolbar)
@@ -593,6 +599,10 @@ class PysolMenubarTkCommon:
             label=n_("Enable highlight same &rank"),
             variable=self.tkopt.highlight_samerank,
             command=self.mOptEnableHighlightSameRank)
+        submenu.add_checkbutton(
+            label=n_("Enable face-down &peek"),
+            variable=self.tkopt.peek_facedown,
+            command=self.mOptEnablePeekFacedown)
         submenu.add_checkbutton(
             label=n_("Highlight &no matching"),
             variable=self.tkopt.highlight_not_matching,
@@ -684,6 +694,10 @@ class PysolMenubarTkCommon:
             label=n_("Shade &filled stacks"),
             variable=self.tkopt.shade_filled_stacks,
             command=self.mOptShadeFilledStacks)
+        submenu.add_checkbutton(
+            label=n_("&Compact long stacks"),
+            variable=self.tkopt.compact_stacks,
+            command=self.mOptCompactStacks)
         submenu.add_checkbutton(
             label=n_("&Randomize card placement"),
             variable=self.tkopt.randomize_place,
@@ -712,6 +726,10 @@ class PysolMenubarTkCommon:
             label=n_("&Redeal animation"),
             variable=self.tkopt.redeal_animation,
             command=self.mRedealAnimation)
+        submenu.add_checkbutton(
+            label=n_("F&lip animation"),
+            variable=self.tkopt.flip_animation,
+            command=self.mFlipAnimation)
         if Image:
             submenu.add_checkbutton(
                 label=n_("&Winning animation"),
@@ -1520,6 +1538,12 @@ Unsupported game for import.
         self.app.opt.highlight_samerank = self.tkopt.highlight_samerank.get()
         # self.game.updateMenus()
 
+    def mOptEnablePeekFacedown(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.peek_facedown = self.tkopt.peek_facedown.get()
+        # self.game.updateMenus()
+
     def mOptEnableHighlightNotMatching(self, *args):
         if self._cancelDrag(break_pause=False):
             return
@@ -1543,6 +1567,11 @@ Unsupported game for import.
             return
         self.app.opt.redeal_animation = self.tkopt.redeal_animation.get()
 
+    def mFlipAnimation(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.flip_animation = self.tkopt.flip_animation.get()
+
     def mWinAnimation(self, *args):
         if self._cancelDrag(break_pause=False):
             return
@@ -1572,6 +1601,13 @@ Unsupported game for import.
         self.game.endGame(bookmark=1)
         self.game.quitGame(bookmark=1)
 
+    def mOptCompactStacks(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.compact_stacks = self.tkopt.compact_stacks.get()
+        self.game.endGame(bookmark=1)
+        self.game.quitGame(bookmark=1)
+
     def mOptMahjonggShowRemoved(self, *args):
         if self._cancelDrag():
             return
